@@ -32,15 +32,9 @@ FAILEDOPERATION_FLOWCREATEERROR = 'FailedOperation.FlowCreateError'
 # Failed to query the backup policy. Please try again later. If the problem persists, please contact customer service.
 FAILEDOPERATION_GETBACKUPSTRATEGYERROR = 'FailedOperation.GetBackupStrategyError'
 
-# Insufficient account balance.
-FAILEDOPERATION_INSUFFICIENTBALANCE = 'FailedOperation.InsufficientBalance'
-
 # Operation failed ({{1}}). Please try again later. If the problem persists, please contact customer service.
 FAILEDOPERATION_OPERATIONFAILEDERROR = 'FailedOperation.OperationFailedError'
 
-# 
-FAILEDOPERATION_QUERYSPECBYSPECCODEERROR = 'FailedOperation.QuerySpecBySpecCodeError'
-
 # Failed to create the order and make a payment. Please try again later. If the problem persists, please contact customer service.
 FAILEDOPERATION_TRADECREATEORDERERROR = 'FailedOperation.TradeCreateOrderError'
 
@@ -65,6 +59,9 @@ INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
 # Failed to query instances by security group.
 INTERNALERROR_LISTINSTANCEFAILED = 'InternalError.ListInstanceFailed'
 
+# Public network operation failed.
+INTERNALERROR_OPERATEWANFAIL = 'InternalError.OperateWanFail'
+
 # Unsupported operation.
 INTERNALERROR_OPERATIONNOTSUPPORT = 'InternalError.OperationNotSupport'
 
@@ -83,6 +80,12 @@ INVALIDPARAMETER = 'InvalidParameter'
 # The current instance cannot be isolated.
 INVALIDPARAMETER_ISOLATENOTALLOWED = 'InvalidParameter.IsolateNotAllowed'
 
+# The account already exists.
+INVALIDPARAMETERVALUE_ACCOUNTALREADYEXISTERROR = 'InvalidParameterValue.AccountAlreadyExistError'
+
+# The account already exists.
+INVALIDPARAMETERVALUE_ACCOUNTEXIST = 'InvalidParameterValue.AccountExist'
+
 # No cluster found.
 INVALIDPARAMETERVALUE_CLUSTERNOTFOUND = 'InvalidParameterValue.ClusterNotFound'
 
@@ -95,6 +98,9 @@ INVALIDPARAMETERVALUE_DBMODENOTSERVERLESSERROR = 'InvalidParameterValue.DbModeNo
 # No order ID found.
 INVALIDPARAMETERVALUE_DEALNAMENOTFOUND = 'InvalidParameterValue.DealNameNotFound'
 
+# Taskflow ID doesn’t exist.
+INVALIDPARAMETERVALUE_FLOWNOTFOUND = 'InvalidParameterValue.FlowNotFound'
+
 # The instance name contains invalid characters.
 INVALIDPARAMETERVALUE_ILLEGALINSTANCENAME = 'InvalidParameterValue.IllegalInstanceName'
 
@@ -107,6 +113,9 @@ INVALIDPARAMETERVALUE_ILLEGALPASSWORD = 'InvalidParameterValue.IllegalPassword'
 # The instance does not exist.
 INVALIDPARAMETERVALUE_INSTANCENOTFOUND = 'InvalidParameterValue.InstanceNotFound'
 
+# The operation is not allowed for system account.
+INVALIDPARAMETERVALUE_INTERNALACCOUNT = 'InvalidParameterValue.InternalAccount'
+
 # Invalid instance version.
 INVALIDPARAMETERVALUE_INVALIDDBVERSION = 'InvalidParameterValue.InvalidDBVersion'
 
@@ -119,9 +128,6 @@ INVALIDPARAMETERVALUE_INVALIDREGIONIDERROR = 'InvalidParameterValue.InvalidRegio
 # Invalid instance specification.
 INVALIDPARAMETERVALUE_INVALIDSPEC = 'InvalidParameterValue.InvalidSpec'
 
-# Invalid availability zone ({{1}}).
-INVALIDPARAMETERVALUE_INVALIDZONEIDERROR = 'InvalidParameterValue.InvalidZoneIdError'
-
 # The parameters (`{{1}}` and `{{2}}`) cannot be set at the same time.
 INVALIDPARAMETERVALUE_PARAMBOTHSETERROR = 'InvalidParameterValue.ParamBothSetError'
 
@@ -167,7 +173,7 @@ OPERATIONDENIED_SERVERLESSINSTANCESTATUSDENIED = 'OperationDenied.ServerlessInst
 # You need to verify your identity to make a purchase.
 OPERATIONDENIED_USERNOTAUTHENTICATEDERROR = 'OperationDenied.UserNotAuthenticatedError'
 
-# 
+# Unsupported version: {{1}}
 OPERATIONDENIED_VERSIONNOTSUPPORTERROR = 'OperationDenied.VersionNotSupportError'
 
 # The cluster ({{1}}) does not exist.
@@ -176,7 +182,7 @@ RESOURCENOTFOUND_CLUSTERNOTFOUNDERROR = 'ResourceNotFound.ClusterNotFoundError'
 # The instance ({{1}}) does not exist.
 RESOURCENOTFOUND_INSTANCENOTFOUNDERROR = 'ResourceNotFound.InstanceNotFoundError'
 
-# 
+# The resource corresponding to the parameter ({{1}}) doesn’t exist.
 RESOURCENOTFOUND_RESOURCEERROR = 'ResourceNotFound.ResourceError'
 
 # Failed to lock the instance, so the operation cannot be performed temporarily.
@@ -185,8 +191,5 @@ RESOURCEUNAVAILABLE_INSTANCELOCKFAIL = 'ResourceUnavailable.InstanceLockFail'
 # The instance is exceptional, so the operation cannot be performed temporarily.
 RESOURCEUNAVAILABLE_INSTANCESTATUSABNORMAL = 'ResourceUnavailable.InstanceStatusAbnormal'
 
-# Users who haven't completed identity verification cannot make purchases.
-UNAUTHORIZEDOPERATION_NOTREALNAMEACCOUNT = 'UnauthorizedOperation.NotRealNameAccount'
-
 # CAM authentication failed.
 UNAUTHORIZEDOPERATION_PERMISSIONDENIED = 'UnauthorizedOperation.PermissionDenied'
