@@ -27,7 +27,7 @@ class EmrClient(AbstractClient):
 
 
     def CreateInstance(self, request):
-        """This API is used to create EMR instance.
+        """This API is used to create an EMR cluster instance.
 
         :param request: Request instance for CreateInstance.
         :type request: :class:`tencentcloud.emr.v20190103.models.CreateInstanceRequest`
@@ -36,7 +36,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateInstance", params)
+            headers = request.headers
+            body = self.call("CreateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateInstanceResponse()
@@ -64,7 +65,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClusterNodes", params)
+            headers = request.headers
+            body = self.call("DescribeClusterNodes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClusterNodesResponse()
@@ -92,7 +94,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstances", params)
+            headers = request.headers
+            body = self.call("DescribeInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstancesResponse()
@@ -120,7 +123,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceCreateInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceCreateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceCreateInstanceResponse()
@@ -148,7 +152,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceRenewInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceRenewInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceRenewInstanceResponse()
@@ -176,7 +181,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceScaleOutInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceScaleOutInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceScaleOutInstanceResponse()
@@ -204,7 +210,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquiryPriceUpdateInstance", params)
+            headers = request.headers
+            body = self.call("InquiryPriceUpdateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquiryPriceUpdateInstanceResponse()
@@ -232,7 +239,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ScaleOutInstance", params)
+            headers = request.headers
+            body = self.call("ScaleOutInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ScaleOutInstanceResponse()
@@ -260,7 +268,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TerminateInstance", params)
+            headers = request.headers
+            body = self.call("TerminateInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TerminateInstanceResponse()
@@ -288,7 +297,8 @@ class EmrClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("TerminateTasks", params)
+            headers = request.headers
+            body = self.call("TerminateTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.TerminateTasksResponse()
