@@ -18,24 +18,24 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
-class AssignClientCreditRequest(AbstractModel):
-    """AssignClientCredit request structure.
+class AllocateCustomerCreditRequest(AbstractModel):
+    """AllocateCustomerCredit request structure.
 
     """
 
     def __init__(self):
         r"""
-        :param QuotaNum: Specific value of the credit allocated to the customer
-        :type QuotaNum: float
+        :param AddedCredit: Specific value of the credit allocated to the customer
+        :type AddedCredit: float
         :param ClientUin: Customer UIN
         :type ClientUin: int
         """
-        self.QuotaNum = None
+        self.AddedCredit = None
         self.ClientUin = None
 
 
     def _deserialize(self, params):
-        self.QuotaNum = params.get("QuotaNum")
+        self.AddedCredit = params.get("AddedCredit")
         self.ClientUin = params.get("ClientUin")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
@@ -46,8 +46,8 @@ class AssignClientCreditRequest(AbstractModel):
         
 
 
-class AssignClientCreditResponse(AbstractModel):
-    """AssignClientCredit response structure.
+class AllocateCustomerCreditResponse(AbstractModel):
+    """AllocateCustomerCredit response structure.
 
     """
 
@@ -212,78 +212,129 @@ class GetCountryCodesResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class QueryAgentCreditRequest(AbstractModel):
-    """QueryAgentCredit request structure.
-
-    """
-
-
-class QueryAgentCreditResponse(AbstractModel):
-    """QueryAgentCredit response structure.
+class QueryCreditAllocationHistoryData(AbstractModel):
+    """Returned information for querying the credit allocation records of reseller’s customer
 
     """
 
     def __init__(self):
         r"""
-        :param AssignedCreditAmount: Allocated credit
-        :type AssignedCreditAmount: float
-        :param CustomerCreditAmount: Total credit
-        :type CustomerCreditAmount: float
-        :param RemainingCreditAmount: Remaining credit
-        :type RemainingCreditAmount: float
+        :param AllocatedTime: Allocation time
+        :type AllocatedTime: str
+        :param Operator: Operator
+        :type Operator: str
+        :param Credit: Allocated credit value
+        :type Credit: float
+        """
+        self.AllocatedTime = None
+        self.Operator = None
+        self.Credit = None
+
+
+    def _deserialize(self, params):
+        self.AllocatedTime = params.get("AllocatedTime")
+        self.Operator = params.get("Operator")
+        self.Credit = params.get("Credit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class QueryCreditAllocationHistoryRequest(AbstractModel):
+    """QueryCreditAllocationHistory request structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClientUin: Customer UIN
+        :type ClientUin: int
+        :param Page: Page number
+        :type Page: int
+        :param PageSize: Number of data entries per page
+        :type PageSize: int
+        """
+        self.ClientUin = None
+        self.Page = None
+        self.PageSize = None
+
+
+    def _deserialize(self, params):
+        self.ClientUin = params.get("ClientUin")
+        self.Page = params.get("Page")
+        self.PageSize = params.get("PageSize")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class QueryCreditAllocationHistoryResponse(AbstractModel):
+    """QueryCreditAllocationHistory response structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Total: Total number of records
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type Total: int
+        :param History: List of record details
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type History: list of QueryCreditAllocationHistoryData
         :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
         :type RequestId: str
         """
-        self.AssignedCreditAmount = None
-        self.CustomerCreditAmount = None
-        self.RemainingCreditAmount = None
+        self.Total = None
+        self.History = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
-        self.AssignedCreditAmount = params.get("AssignedCreditAmount")
-        self.CustomerCreditAmount = params.get("CustomerCreditAmount")
-        self.RemainingCreditAmount = params.get("RemainingCreditAmount")
+        self.Total = params.get("Total")
+        if params.get("History") is not None:
+            self.History = []
+            for item in params.get("History"):
+                obj = QueryCreditAllocationHistoryData()
+                obj._deserialize(item)
+                self.History.append(obj)
         self.RequestId = params.get("RequestId")
 
 
-class QueryClientListItem(AbstractModel):
-    """Reseller's customer list
+class QueryCustomersCreditData(AbstractModel):
+    """Complex type of output parameters for querying customer's credit
 
     """
 
     def __init__(self):
         r"""
         :param Name: Name
-Note: this field may return null, indicating that no valid values can be obtained.
         :type Name: str
         :param Type: Type
-Note: this field may return null, indicating that no valid values can be obtained.
         :type Type: str
         :param Mobile: Phone
-Note: this field may return null, indicating that no valid values can be obtained.
         :type Mobile: str
         :param Email: Email
-Note: this field may return null, indicating that no valid values can be obtained.
         :type Email: str
         :param Arrears: Overdue payment flag
-Note: this field may return null, indicating that no valid values can be obtained.
         :type Arrears: str
         :param AssociationTime: Binding time
-Note: this field may return null, indicating that no valid values can be obtained.
         :type AssociationTime: str
         :param RecentExpiry: Expiration time
-Note: this field may return null, indicating that no valid values can be obtained.
         :type RecentExpiry: str
-        :param ClientUin: Customer UIN
-Note: this field may return null, indicating that no valid values can be obtained.
+        :param ClientUin: The UIN of reseller’s customer
         :type ClientUin: int
-        :param CreditAmount: Credit granted to customer
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type CreditAmount: float
-        :param RestCreditAmount: Customer's remaining credit
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type RestCreditAmount: float
+        :param Credit: Credit granted to reseller’s customer
+        :type Credit: float
+        :param RemainingCredit: The remaining credit of reseller’s customer
+        :type RemainingCredit: float
         """
         self.Name = None
         self.Type = None
@@ -293,8 +344,8 @@ Note: this field may return null, indicating that no valid values can be obtaine
         self.AssociationTime = None
         self.RecentExpiry = None
         self.ClientUin = None
-        self.CreditAmount = None
-        self.RestCreditAmount = None
+        self.Credit = None
+        self.RemainingCredit = None
 
 
     def _deserialize(self, params):
@@ -306,8 +357,8 @@ Note: this field may return null, indicating that no valid values can be obtaine
         self.AssociationTime = params.get("AssociationTime")
         self.RecentExpiry = params.get("RecentExpiry")
         self.ClientUin = params.get("ClientUin")
-        self.CreditAmount = params.get("CreditAmount")
-        self.RestCreditAmount = params.get("RestCreditAmount")
+        self.Credit = params.get("Credit")
+        self.RemainingCredit = params.get("RemainingCredit")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -317,14 +368,14 @@ Note: this field may return null, indicating that no valid values can be obtaine
         
 
 
-class QueryClientListRequest(AbstractModel):
-    """QueryClientList request structure.
+class QueryCustomersCreditRequest(AbstractModel):
+    """QueryCustomersCredit request structure.
 
     """
 
 
-class QueryClientListResponse(AbstractModel):
-    """QueryClientList response structure.
+class QueryCustomersCreditResponse(AbstractModel):
+    """QueryCustomersCredit response structure.
 
     """
 
@@ -332,7 +383,7 @@ class QueryClientListResponse(AbstractModel):
         r"""
         :param Data: Queries the list of customers
 Note: this field may return null, indicating that no valid values can be obtained.
-        :type Data: list of QueryClientListItem
+        :type Data: list of QueryCustomersCreditData
         :param Total: Number of customers
         :type Total: int
         :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
@@ -347,108 +398,43 @@ Note: this field may return null, indicating that no valid values can be obtaine
         if params.get("Data") is not None:
             self.Data = []
             for item in params.get("Data"):
-                obj = QueryClientListItem()
+                obj = QueryCustomersCreditData()
                 obj._deserialize(item)
                 self.Data.append(obj)
         self.Total = params.get("Total")
         self.RequestId = params.get("RequestId")
 
 
-class QueryCreditHistoryRequest(AbstractModel):
-    """QueryCreditHistory request structure.
+class QueryPartnerCreditRequest(AbstractModel):
+    """QueryPartnerCredit request structure.
+
+    """
+
+
+class QueryPartnerCreditResponse(AbstractModel):
+    """QueryPartnerCredit response structure.
 
     """
 
     def __init__(self):
         r"""
-        :param ClientUin: Customer UIN
-        :type ClientUin: int
-        :param Page: Page number
-        :type Page: int
-        :param PageRow: Number of data entries per page
-        :type PageRow: int
-        """
-        self.ClientUin = None
-        self.Page = None
-        self.PageRow = None
-
-
-    def _deserialize(self, params):
-        self.ClientUin = params.get("ClientUin")
-        self.Page = params.get("Page")
-        self.PageRow = params.get("PageRow")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class QueryCreditHistoryResponse(AbstractModel):
-    """QueryCreditHistory response structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param Total: Total number of records
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type Total: int
-        :param History: List of record details
-Note: this field may return null, indicating that no valid values can be obtained.
-        :type History: list of QueryUinCreditHistoryData
+        :param AllocatedCredit: Allocated credit
+        :type AllocatedCredit: float
+        :param TotalCredit: Total credit
+        :type TotalCredit: float
+        :param RemainingCredit: Remaining credit
+        :type RemainingCredit: float
         :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
         :type RequestId: str
         """
-        self.Total = None
-        self.History = None
+        self.AllocatedCredit = None
+        self.TotalCredit = None
+        self.RemainingCredit = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
-        self.Total = params.get("Total")
-        if params.get("History") is not None:
-            self.History = []
-            for item in params.get("History"):
-                obj = QueryUinCreditHistoryData()
-                obj._deserialize(item)
-                self.History.append(obj)
-        self.RequestId = params.get("RequestId")
-
-
-class QueryUinCreditHistoryData(AbstractModel):
-    """Queries reseller's credit allocation records and returns individual records
-
-    """
-
-    def __init__(self):
-        r"""
-        :param CreditAssignUin: Credit allocatee UIN
-        :type CreditAssignUin: int
-        :param AssginTime: Allocation time
-        :type AssginTime: str
-        :param Operator: Operator
-        :type Operator: str
-        :param CreditAmount: Allocated credit value
-        :type CreditAmount: float
-        """
-        self.CreditAssignUin = None
-        self.AssginTime = None
-        self.Operator = None
-        self.CreditAmount = None
-
-
-    def _deserialize(self, params):
-        self.CreditAssignUin = params.get("CreditAssignUin")
-        self.AssginTime = params.get("AssginTime")
-        self.Operator = params.get("Operator")
-        self.CreditAmount = params.get("CreditAmount")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
\ No newline at end of file
+        self.AllocatedCredit = params.get("AllocatedCredit")
+        self.TotalCredit = params.get("TotalCredit")
+        self.RemainingCredit = params.get("RemainingCredit")
+        self.RequestId = params.get("RequestId")
\ No newline at end of file
