@@ -36,7 +36,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BindingPolicyObject", params)
+            headers = request.headers
+            body = self.call("BindingPolicyObject", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BindingPolicyObjectResponse()
@@ -64,7 +65,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAlarmNotice", params)
+            headers = request.headers
+            body = self.call("CreateAlarmNotice", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAlarmNoticeResponse()
@@ -92,7 +94,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAlarmPolicy", params)
+            headers = request.headers
+            body = self.call("CreateAlarmPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAlarmPolicyResponse()
@@ -120,7 +123,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreatePolicyGroup", params)
+            headers = request.headers
+            body = self.call("CreatePolicyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreatePolicyGroupResponse()
@@ -148,7 +152,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAlarmNotices", params)
+            headers = request.headers
+            body = self.call("DeleteAlarmNotices", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAlarmNoticesResponse()
@@ -176,7 +181,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAlarmPolicy", params)
+            headers = request.headers
+            body = self.call("DeleteAlarmPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAlarmPolicyResponse()
@@ -204,7 +210,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeletePolicyGroup", params)
+            headers = request.headers
+            body = self.call("DeletePolicyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeletePolicyGroupResponse()
@@ -232,7 +239,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccidentEventList", params)
+            headers = request.headers
+            body = self.call("DescribeAccidentEventList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAccidentEventListResponse()
@@ -260,7 +268,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAlarmEvents", params)
+            headers = request.headers
+            body = self.call("DescribeAlarmEvents", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAlarmEventsResponse()
@@ -290,7 +299,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAlarmHistories", params)
+            headers = request.headers
+            body = self.call("DescribeAlarmHistories", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAlarmHistoriesResponse()
@@ -318,7 +328,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAlarmMetrics", params)
+            headers = request.headers
+            body = self.call("DescribeAlarmMetrics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAlarmMetricsResponse()
@@ -346,7 +357,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAlarmNotice", params)
+            headers = request.headers
+            body = self.call("DescribeAlarmNotice", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAlarmNoticeResponse()
@@ -374,7 +386,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAlarmNoticeCallbacks", params)
+            headers = request.headers
+            body = self.call("DescribeAlarmNoticeCallbacks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAlarmNoticeCallbacksResponse()
@@ -402,7 +415,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAlarmNotices", params)
+            headers = request.headers
+            body = self.call("DescribeAlarmNotices", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAlarmNoticesResponse()
@@ -430,7 +444,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAlarmPolicies", params)
+            headers = request.headers
+            body = self.call("DescribeAlarmPolicies", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAlarmPoliciesResponse()
@@ -458,7 +473,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAlarmPolicy", params)
+            headers = request.headers
+            body = self.call("DescribeAlarmPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAlarmPolicyResponse()
@@ -486,7 +502,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAllNamespaces", params)
+            headers = request.headers
+            body = self.call("DescribeAllNamespaces", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAllNamespacesResponse()
@@ -514,7 +531,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBaseMetrics", params)
+            headers = request.headers
+            body = self.call("DescribeBaseMetrics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBaseMetricsResponse()
@@ -542,7 +560,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBasicAlarmList", params)
+            headers = request.headers
+            body = self.call("DescribeBasicAlarmList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBasicAlarmListResponse()
@@ -570,7 +589,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBindingPolicyObjectList", params)
+            headers = request.headers
+            body = self.call("DescribeBindingPolicyObjectList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBindingPolicyObjectListResponse()
@@ -598,7 +618,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeConditionsTemplateList", params)
+            headers = request.headers
+            body = self.call("DescribeConditionsTemplateList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeConditionsTemplateListResponse()
@@ -626,7 +647,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMonitorTypes", params)
+            headers = request.headers
+            body = self.call("DescribeMonitorTypes", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMonitorTypesResponse()
@@ -654,7 +676,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePolicyConditionList", params)
+            headers = request.headers
+            body = self.call("DescribePolicyConditionList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePolicyConditionListResponse()
@@ -682,7 +705,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePolicyGroupInfo", params)
+            headers = request.headers
+            body = self.call("DescribePolicyGroupInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePolicyGroupInfoResponse()
@@ -710,7 +734,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribePolicyGroupList", params)
+            headers = request.headers
+            body = self.call("DescribePolicyGroupList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribePolicyGroupListResponse()
@@ -738,7 +763,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeProductEventList", params)
+            headers = request.headers
+            body = self.call("DescribeProductEventList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeProductEventListResponse()
@@ -766,7 +792,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeStatisticData", params)
+            headers = request.headers
+            body = self.call("DescribeStatisticData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeStatisticDataResponse()
@@ -797,7 +824,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetMonitorData", params)
+            headers = request.headers
+            body = self.call("GetMonitorData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetMonitorDataResponse()
@@ -825,7 +853,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAlarmNotice", params)
+            headers = request.headers
+            body = self.call("ModifyAlarmNotice", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAlarmNoticeResponse()
@@ -853,7 +882,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAlarmPolicyCondition", params)
+            headers = request.headers
+            body = self.call("ModifyAlarmPolicyCondition", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAlarmPolicyConditionResponse()
@@ -881,7 +911,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAlarmPolicyInfo", params)
+            headers = request.headers
+            body = self.call("ModifyAlarmPolicyInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAlarmPolicyInfoResponse()
@@ -909,7 +940,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAlarmPolicyNotice", params)
+            headers = request.headers
+            body = self.call("ModifyAlarmPolicyNotice", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAlarmPolicyNoticeResponse()
@@ -937,7 +969,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAlarmPolicyStatus", params)
+            headers = request.headers
+            body = self.call("ModifyAlarmPolicyStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAlarmPolicyStatusResponse()
@@ -965,7 +998,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAlarmPolicyTasks", params)
+            headers = request.headers
+            body = self.call("ModifyAlarmPolicyTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAlarmPolicyTasksResponse()
@@ -993,7 +1027,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAlarmReceivers", params)
+            headers = request.headers
+            body = self.call("ModifyAlarmReceivers", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAlarmReceiversResponse()
@@ -1021,7 +1056,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyPolicyGroup", params)
+            headers = request.headers
+            body = self.call("ModifyPolicyGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyPolicyGroupResponse()
@@ -1055,7 +1091,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PutMonitorData", params)
+            headers = request.headers
+            body = self.call("PutMonitorData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PutMonitorDataResponse()
@@ -1083,7 +1120,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendCustomAlarmMsg", params)
+            headers = request.headers
+            body = self.call("SendCustomAlarmMsg", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendCustomAlarmMsgResponse()
@@ -1112,7 +1150,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetDefaultAlarmPolicy", params)
+            headers = request.headers
+            body = self.call("SetDefaultAlarmPolicy", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetDefaultAlarmPolicyResponse()
@@ -1140,7 +1179,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UnBindingAllPolicyObject", params)
+            headers = request.headers
+            body = self.call("UnBindingAllPolicyObject", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UnBindingAllPolicyObjectResponse()
@@ -1168,7 +1208,8 @@ class MonitorClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UnBindingPolicyObject", params)
+            headers = request.headers
+            body = self.call("UnBindingPolicyObject", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UnBindingPolicyObjectResponse()
