@@ -41,6 +41,9 @@ FAILEDOPERATION_LANGUAGENOTSUPPORT = 'FailedOperation.LanguageNotSupport'
 # Not a Hong Kong identity card.
 FAILEDOPERATION_NOHKIDCARD = 'FailedOperation.NoHKIDCard'
 
+# Non-Malaysian ID cards
+FAILEDOPERATION_NOMASIDCARD = 'FailedOperation.NoMASIDCard'
+
 # Not a passport.
 FAILEDOPERATION_NOPASSPORT = 'FailedOperation.NoPassport'
 
