@@ -46,110 +46,6 @@ class Attachment(AbstractModel):
         
 
 
-class BatchSendEmailRequest(AbstractModel):
-    """BatchSendEmail request structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param FromEmailAddress: Sender address. Enter a sender address, for example, noreply@mail.qcloud.com. To display the sender name, enter the address in the following format:
-Sender <email address>, for example:
-Tencent Cloud team <noreply@mail.qcloud.com>
-        :type FromEmailAddress: str
-        :param ReceiverId: Recipient group ID
-        :type ReceiverId: int
-        :param Subject: Email subject
-        :type Subject: str
-        :param TaskType: Task type. `1`: immediate; `2`: scheduled; `3`: recurring
-        :type TaskType: int
-        :param ReplyToAddresses: Reply-to address. You can enter a valid personal email address that can receive emails. If this parameter is left empty, reply emails will be sent to Tencent Cloud.
-        :type ReplyToAddresses: str
-        :param Template: Template when emails are sent using a template
-        :type Template: :class:`tencentcloud.ses.v20201002.models.Template`
-        :param Simple: Email content when emails are sent by calling the API. This parameter is currently unavailable.
-        :type Simple: :class:`tencentcloud.ses.v20201002.models.Simple`
-        :param Attachments: Attachment parameters to set when you need to send attachments. This parameter is currently unavailable.
-        :type Attachments: list of Attachment
-        :param CycleParam: Parameter required for a recurring sending task
-        :type CycleParam: :class:`tencentcloud.ses.v20201002.models.CycleEmailParam`
-        :param TimedParam: Parameter required for a scheduled sending task
-        :type TimedParam: :class:`tencentcloud.ses.v20201002.models.TimedEmailParam`
-        :param Unsubscribe: Unsubscribe option. `1`: provides an unsubscribe link; `0`: does not provide an unsubscribe link
-        :type Unsubscribe: str
-        :param ADLocation: 
-        :type ADLocation: int
-        """
-        self.FromEmailAddress = None
-        self.ReceiverId = None
-        self.Subject = None
-        self.TaskType = None
-        self.ReplyToAddresses = None
-        self.Template = None
-        self.Simple = None
-        self.Attachments = None
-        self.CycleParam = None
-        self.TimedParam = None
-        self.Unsubscribe = None
-        self.ADLocation = None
-
-
-    def _deserialize(self, params):
-        self.FromEmailAddress = params.get("FromEmailAddress")
-        self.ReceiverId = params.get("ReceiverId")
-        self.Subject = params.get("Subject")
-        self.TaskType = params.get("TaskType")
-        self.ReplyToAddresses = params.get("ReplyToAddresses")
-        if params.get("Template") is not None:
-            self.Template = Template()
-            self.Template._deserialize(params.get("Template"))
-        if params.get("Simple") is not None:
-            self.Simple = Simple()
-            self.Simple._deserialize(params.get("Simple"))
-        if params.get("Attachments") is not None:
-            self.Attachments = []
-            for item in params.get("Attachments"):
-                obj = Attachment()
-                obj._deserialize(item)
-                self.Attachments.append(obj)
-        if params.get("CycleParam") is not None:
-            self.CycleParam = CycleEmailParam()
-            self.CycleParam._deserialize(params.get("CycleParam"))
-        if params.get("TimedParam") is not None:
-            self.TimedParam = TimedEmailParam()
-            self.TimedParam._deserialize(params.get("TimedParam"))
-        self.Unsubscribe = params.get("Unsubscribe")
-        self.ADLocation = params.get("ADLocation")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class BatchSendEmailResponse(AbstractModel):
-    """BatchSendEmail response structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param TaskId: Sending task ID
-        :type TaskId: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
-        self.TaskId = None
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        self.TaskId = params.get("TaskId")
-        self.RequestId = params.get("RequestId")
-
-
 class BlackEmailAddress(AbstractModel):
     """Email address blocklist structure, including the blocklisted address and the time when it is blocklisted.
 
@@ -281,53 +177,6 @@ class CreateEmailIdentityResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class CreateEmailTemplateRequest(AbstractModel):
-    """CreateEmailTemplate request structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param TemplateName: Template name.
-        :type TemplateName: str
-        :param TemplateContent: Template content.
-        :type TemplateContent: :class:`tencentcloud.ses.v20201002.models.TemplateContent`
-        """
-        self.TemplateName = None
-        self.TemplateContent = None
-
-
-    def _deserialize(self, params):
-        self.TemplateName = params.get("TemplateName")
-        if params.get("TemplateContent") is not None:
-            self.TemplateContent = TemplateContent()
-            self.TemplateContent._deserialize(params.get("TemplateContent"))
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class CreateEmailTemplateResponse(AbstractModel):
-    """CreateEmailTemplate response structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        self.RequestId = params.get("RequestId")
-
-
 class CreateReceiverDetailRequest(AbstractModel):
     """CreateReceiverDetail request structure.
 
@@ -866,72 +715,6 @@ class GetEmailTemplateResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class GetSendEmailStatusRequest(AbstractModel):
-    """GetSendEmailStatus request structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param RequestDate: Sent date. This parameter is required. You can only query the sending status for a single date at a time.
-        :type RequestDate: str
-        :param Offset: Offset. Default value: `0`
-        :type Offset: int
-        :param Limit: Maximum number of pulled entries. The maximum value is `100`.
-        :type Limit: int
-        :param MessageId: `MessageId` field returned by the `SendMail` API
-        :type MessageId: str
-        :param ToEmailAddress: Recipient email address
-        :type ToEmailAddress: str
-        """
-        self.RequestDate = None
-        self.Offset = None
-        self.Limit = None
-        self.MessageId = None
-        self.ToEmailAddress = None
-
-
-    def _deserialize(self, params):
-        self.RequestDate = params.get("RequestDate")
-        self.Offset = params.get("Offset")
-        self.Limit = params.get("Limit")
-        self.MessageId = params.get("MessageId")
-        self.ToEmailAddress = params.get("ToEmailAddress")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class GetSendEmailStatusResponse(AbstractModel):
-    """GetSendEmailStatus response structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param EmailStatusList: Email sending status list
-        :type EmailStatusList: list of SendEmailStatus
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
-        self.EmailStatusList = None
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        if params.get("EmailStatusList") is not None:
-            self.EmailStatusList = []
-            for item in params.get("EmailStatusList"):
-                obj = SendEmailStatus()
-                obj._deserialize(item)
-                self.EmailStatusList.append(obj)
-        self.RequestId = params.get("RequestId")
-
-
 class GetStatisticsReportRequest(AbstractModel):
     """GetStatisticsReport request structure.
 
@@ -1467,101 +1250,6 @@ class SendEmailResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class SendEmailStatus(AbstractModel):
-    """Describes the email sending status.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param MessageId: `MessageId` field returned by the `SendEmail` API
-        :type MessageId: str
-        :param ToEmailAddress: Recipient email address
-        :type ToEmailAddress: str
-        :param FromEmailAddress: Sender email address
-        :type FromEmailAddress: str
-        :param SendStatus: Tencent Cloud processing status:
-0: successful.
-1001: internal system exception.
-1002: internal system exception.
-1003: internal system exception.
-1003: internal system exception.
-1004: email sending timeout.
-1005: internal system exception.
-1006: you have sent too many emails to the same address in a short period.
-1007: the email address is in the blocklist.
-1009: internal system exception.
-1010: daily email sending limit exceeded.
-1011: no permission to send custom content. Use a template.
-2001: no results found.
-3007: invalid template ID or unavailable template.
-3008: template status exception.
-3009: no permission to use this template.
-3010: the format of the `TemplateData` field is incorrect. 
-3014: unable to send the email because the sender domain is not verified.
-3020: the recipient email address is in the blocklist.
-3024: failed to pre-check the email address format.
-3030: email sending is restricted temporarily due to high bounce rate.
-3033: the account has insufficient balance or overdue payment.
-        :type SendStatus: int
-        :param DeliverStatus: Recipient processing status:
-0: Tencent Cloud has accepted the request and added it to the send queue.
-1: the email is delivered successfully, `DeliverTime` indicates the time when the email is delivered successfully.
-2: the email is discarded. `DeliverMessage` indicates the reason for discarding.
-3: the recipient's ESP rejects the email, probably because the email address does not exist or due to other reasons.
-8: the email is delayed by the ESP. `DeliverMessage` indicates the reason for delay.
-        :type DeliverStatus: int
-        :param DeliverMessage: Description of the recipient processing status
-        :type DeliverMessage: str
-        :param RequestTime: Timestamp when the request arrives at Tencent Cloud
-        :type RequestTime: int
-        :param DeliverTime: Timestamp when Tencent Cloud delivers the email
-        :type DeliverTime: int
-        :param UserOpened: Whether the recipient has opened the email
-        :type UserOpened: bool
-        :param UserClicked: Whether the recipient has clicked the links in the email
-        :type UserClicked: bool
-        :param UserUnsubscribed: Whether the recipient has unsubscribed from emails sent by the sender
-        :type UserUnsubscribed: bool
-        :param UserComplainted: Whether the recipient has reported the sender
-        :type UserComplainted: bool
-        """
-        self.MessageId = None
-        self.ToEmailAddress = None
-        self.FromEmailAddress = None
-        self.SendStatus = None
-        self.DeliverStatus = None
-        self.DeliverMessage = None
-        self.RequestTime = None
-        self.DeliverTime = None
-        self.UserOpened = None
-        self.UserClicked = None
-        self.UserUnsubscribed = None
-        self.UserComplainted = None
-
-
-    def _deserialize(self, params):
-        self.MessageId = params.get("MessageId")
-        self.ToEmailAddress = params.get("ToEmailAddress")
-        self.FromEmailAddress = params.get("FromEmailAddress")
-        self.SendStatus = params.get("SendStatus")
-        self.DeliverStatus = params.get("DeliverStatus")
-        self.DeliverMessage = params.get("DeliverMessage")
-        self.RequestTime = params.get("RequestTime")
-        self.DeliverTime = params.get("DeliverTime")
-        self.UserOpened = params.get("UserOpened")
-        self.UserClicked = params.get("UserClicked")
-        self.UserUnsubscribed = params.get("UserUnsubscribed")
-        self.UserComplainted = params.get("UserComplainted")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
 class SendTaskData(AbstractModel):
     """Email sending task data
 
@@ -1864,57 +1552,6 @@ class UpdateEmailIdentityResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class UpdateEmailTemplateRequest(AbstractModel):
-    """UpdateEmailTemplate request structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param TemplateContent: Template content.
-        :type TemplateContent: :class:`tencentcloud.ses.v20201002.models.TemplateContent`
-        :param TemplateID: Template ID.
-        :type TemplateID: int
-        :param TemplateName: Template name.
-        :type TemplateName: str
-        """
-        self.TemplateContent = None
-        self.TemplateID = None
-        self.TemplateName = None
-
-
-    def _deserialize(self, params):
-        if params.get("TemplateContent") is not None:
-            self.TemplateContent = TemplateContent()
-            self.TemplateContent._deserialize(params.get("TemplateContent"))
-        self.TemplateID = params.get("TemplateID")
-        self.TemplateName = params.get("TemplateName")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class UpdateEmailTemplateResponse(AbstractModel):
-    """UpdateEmailTemplate response structure.
-
-    """
-
-    def __init__(self):
-        r"""
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        self.RequestId = params.get("RequestId")
-
-
 class Volume(AbstractModel):
     """Statistics structure.
 
