@@ -29,6 +29,9 @@ INTERNALERROR_CREATESERVICEERROR = 'InternalError.CreateServiceError'
 # The server is busy. Retry later.
 INTERNALERROR_DEFAULTINTERNALERROR = 'InternalError.DefaultInternalError'
 
+# Failed to delete the application
+INTERNALERROR_DELETESERVICEERROR = 'InternalError.DeleteServiceError'
+
 # Failed to invoke the version deployment
 INTERNALERROR_DEPLOYVERSIONERROR = 'InternalError.DeployVersionError'
 
@@ -38,7 +41,7 @@ INTERNALERROR_DESCRIBERUNPODLISTERROR = 'InternalError.DescribeRunPodListError'
 # Failed to restart
 INTERNALERROR_RESTARTAPPLICATIONERROR = 'InternalError.RestartApplicationError'
 
-# 
+# Failed to update the ingress
 INTERNALERROR_UPDATEINGRESSERROR = 'InternalError.UpdateIngressError'
 
 # The version number is invalid.
@@ -50,6 +53,9 @@ INVALIDPARAMETERVALUE_NAMESPACEDUPLICATEERROR = 'InvalidParameterValue.Namespace
 # Failed to create the environment. The upper limit of environment is reached.
 INVALIDPARAMETERVALUE_NAMESPACEREACHMAXIMUM = 'InvalidParameterValue.NamespaceReachMaximum'
 
+# Failed to create the environment. The upper limit of environment is reached.
+INVALIDPARAMETERVALUE_NAMESPACERESOURCEREACHMAXIMUM = 'InvalidParameterValue.NamespaceResourceReachMaximum'
+
 # There are running pods in this application.
 INVALIDPARAMETERVALUE_SERVICEFOUNDRUNNINGVERSION = 'InvalidParameterValue.ServiceFoundRunningVersion'
 
@@ -65,12 +71,18 @@ INVALIDPARAMETERVALUE_VERSIONLOWERCASE = 'InvalidParameterValue.VersionLowerCase
 # There is still traffic routed to this version.
 INVALIDPARAMETERVALUE_VERSIONROUTERATENOTZERO = 'InvalidParameterValue.VersionRouteRateNotZero'
 
+# 
+MISSINGPARAMETER_DEPLOYVERSIONNULL = 'MissingParameter.DeployVersionNull'
+
 # The environment ID can not be left empty.
 MISSINGPARAMETER_NAMESPACEIDNULL = 'MissingParameter.NamespaceIdNull'
 
 # The target microservice is offline.
 RESOURCENOTFOUND_MICROSERVICEOFFLINE = 'ResourceNotFound.MicroserviceOffline'
 
+# The environment does not exist.
+RESOURCENOTFOUND_NAMESPACENOTFOUND = 'ResourceNotFound.NamespaceNotFound'
+
 # The application is not found.
 RESOURCENOTFOUND_SERVICENOTFOUND = 'ResourceNotFound.ServiceNotFound'
 
@@ -80,7 +92,7 @@ RESOURCENOTFOUND_SERVICERUNNINGVERSIONNOTFOUND = 'ResourceNotFound.ServiceRunnin
 # The environment corresponding to this version is not found.
 RESOURCENOTFOUND_VERSIONNAMESPACENOTFOUND = 'ResourceNotFound.VersionNamespaceNotFound'
 
-# 
+# The environment corresponding to this version is not found.
 RESOURCENOTFOUND_VERSIONSERVICENOTFOUND = 'ResourceNotFound.VersionServiceNotFound'
 
 # Waiting for the installation of addon
